@@ -5,7 +5,8 @@ set -o nounset
 apt-get update
 apt-get install -y python-setuptools python-pip curl bzip2 build-essential libaio-dev
 
-pip install lockfile boto cloudbench
+pip uninstall --yes python-novaclient
+pip install lockfile boto pyrax cloudbench
 
 FIO_BUILD=/tmp/$$-build/
 
